#include "Includes_PES.h"
//#include "I2C_PES.h"
#include    <xc.h>

// For PIC16F1825

void I2C_open( unsigned char sync_mode, unsigned char slew )
{
  SSP1STAT &= 0x3F;                // power on state
  SSP1CON1 = 0x00;                 // power on state
  SSP1CON2 = 0x28;  // 00;                 // power on state
  SSP1CON1 |= sync_mode;           // select serial mode
  SSP1STAT |= slew;                // slew rate on/off

  I2C_SCL = 1;
  I2C_SDA = 1;
  SSP1CON1 |= SSPEN;              // enable synchronous serial port

}

void I2C_close( void )
{
  SSP1CON1 &= 0xDF;                // disable synchronous serial port
}

// Function Purpose: Configure I2C module
void I2C_init(void)
{	
	SDA_DIR = 1;		// Make SDA and 
	SCK_DIR = 1;		// SCK pins input
	SSP1ADD  = ((_XTAL_FREQ/4000)/I2C_SPEED) - 1;
	SSP1STAT = 0x80;		// Slew Rate control is disabled
	SSP1CON1  = 0x28;		// Select and enable I2C in master mode
}

// generates Wait condition until I2C bus is Idle.
void    I2C_idle(void)
{   // 4:ACKEN, 3:RCEN; 2:PEN; 1:RSEN; 0:SEN
    while ((SSP1CON2 & 0x1F) || (SSP1STATbits.R_nW));    // WAS "|" 1 means transmit in progress
}

// Function Purpose: I2C_Start sends start bit sequence
void I2C_start(void)
{
    if(SSP1CON1bits.SSPEN == 0)
       SSP1CON1 = 0x28;
    SSP1CON2bits.SEN = 1; // Send start bit
    while(SSP1CON2bits.SEN);
}

/*
void I2C_start(void)
{
    SSP1CON2bits.SEN = 1;			// Send start bit
    while(SSP1CON2bits.SEN);
}
 */

// Function Purpose: I2C_ReStart sends start bit sequence
void I2C_restart(void)
{
	SSP1CON2bits.RSEN = 1;			// Send Restart bit
        while(SSP1CON2bits.RSEN);
}

//Function : I2C_Stop sends stop bit sequence
void I2C_stop(void)
{
	SSP1CON2bits.PEN = 1;			// Send stop bit
	while(SSP1CON2bits.PEN);		// Wait for it to complete
}

//Function : I2C_Send_ACK sends ACK bit sequence
void I2C_send_ACK(void)
{
    SSP1CON2bits.ACKDT=0;		// 0 means ACK
    SSP1CON2bits.ACKEN=1;
    while(RCEN && SSP1CON2bits.ACKEN);
}

//Function : I2C_Send_NACK sends NACK bit sequence
void I2C_send_NACK(void)
{
    SSP1CON2bits.ACKDT=1;
    SSP1CON2bits.ACKEN=1;
    while(RCEN && SSP1CON2bits.ACKEN);
}


// Function Purpose: I2C_Write_Byte transfers one byte
/*
signed char I2C_write_byte( unsigned char *rdptr,  unsigned char length )
{
//     getsI2C1(  unsigned char *rdptr,  unsigned char length );
	SSPBUF = Byte;		// Send Byte value
	while(!PIR1bits.SSP1IF);		// Wait for it to complete
	PIR1bits.SSP1IF = 0;			// Clear the flag bit
	return ACKSTAT;		// Return ACK/NACK from slave
}


// Function Purpose: I2C_Read_Byte reads one byte
unsigned char I2C_read_byte(void)
{
	RCEN = 1;			// Enable reception of 8 bits
#ifdef  _16F877
	while(!SSPIF);		// Wait for it to complete
	SSPIF = 0;			// Clear the flag bit
#else
#ifdef  _16F1825
	while(!SSP1IF);		// Wait for it to complete
	SSP1IF = 0;			// Clear the flag bit
#endif
#endif
 
    return SSPBUF;		// Return received byte
}
*/

signed char I2C_write( unsigned char data_out )
{
  SSP1BUF = data_out;           // write single byte to SSPBUF
  if ( SSP1CON1bits.WCOL )      // test if write collision occurred
   return ( -1 );              // if WCOL bit is set return negative #
  else
  {
	if( ((SSP1CON1&0x0F)!=0x08) && ((SSP1CON1&0x0F)!=0x0B) )	//Slave mode only
	{
	      SSP1CON1bits.CKP = 1;        // release clock line
	      while ( !PIR1bits.SSP1IF );  // wait until ninth clock pulse received

	      if ( ( !SSP1STATbits.R_nW ) && ( !SSP1STATbits.BF ) )// if R/W=0 and BF=0, NOT ACK was received
	      {
	        return ( -2 );           //return NACK
	      }
		  else
		  {
			return ( 0 );				//return ACK
		  }
	}
	else if( ((SSP1CON1&0x0F)==0x08) || ((SSP1CON1&0x0F)==0x0B) )	//master mode only
	{
	    while( SSP1STATbits.BF );   // wait until write cycle is complete
//	    I2C_idle();                 // ensure module is idle
	    if ( SSP1CON2bits.ACKSTAT ) // test for ACK condition received
	    	 return ( -2 );			// return NACK
		else return ( 0 );              //return ACK
	}

  }
  return(-3);       // to avoid warning
}

unsigned char I2C_read_byte( void )
{
  if( ((SSP1CON1&0x0F)==0x08) || ((SSP1CON1&0x0F)==0x0B) )	//master mode only
    SSP1CON2bits.RCEN = 1;           // enable master for 1 byte reception
  while(!SSP1STATbits.BF);      // wait until byte received
  return(SSP1BUF);              // return with read byte
}
