
#ifndef __I2C_PES_H
#define __I2C_PES_H

#define SDA		RC1			// Pin 9, Data pin for i2c
#define SCK		RC0			// Pin 10, Clock pin for i2c
#define SDA_DIR		TRISC1			// Data pin direction
#define SCK_DIR		TRISC0			// Clock pin direction

/* SSPCON1 REGISTER */
#define   SSPENB    			0b00100000  	/* Enable serial port and configures SCK, SDO, SDI*/
#define   SLAVE_7   			0b00000110     	/* I2C Slave mode, 7-bit address*/
#define   SLAVE_10  			0b00000111    	/* I2C Slave mode, 10-bit address*/
#define   MASTER    			0b00001000     	/* I2C Master mode */
#define   MASTER_FIRMW			0b00001011		//I2C Firmware Controlled Master mode (slave Idle)
#define   SLAVE_7_STSP_INT 		0b00001110		//I2C Slave mode, 7-bit address with Start and Stop bit interrupts enabled
#define   SLAVE_10_STSP_INT 	0b00001111		//I2C Slave mode, 10-bit address with Start and Stop bit interrupts enabled

/* SSPSTAT REGISTER */
#define   SLEW_OFF  			0b10000000  	/* Slew rate disabled for 100kHz mode */
#define   SLEW_ON   			0b00000000  	/* Slew rate enabled for 400kHz mode  */

#define I2C_SCL	TRISCbits.TRISC0
#define I2C_SDA	TRISCbits.TRISC1
// Define i2c speed
#define I2C_SPEED	100				// kbps

//Function Declarations
void            I2C_close( void );
void            I2C_init(void);
void            I2C_idle(void);
void            I2C_open( unsigned char sync_mode, unsigned char slew );
unsigned char   I2C_read_byte(void);
void            I2C_restart(void);
void            I2C_send_ACK(void);
void            I2C_send_NACK(void);
void            I2C_start(void);
void            I2C_stop(void);
//signed char     I2C_write_byte(unsigned char *rdptr,  unsigned char length);
signed char     I2C_write( unsigned char data_out );

#endif
